Module dir

Module dir 

Directory-based Lance Namespace implementation.

This module provides a directory-based implementation of the Lance namespace that stores tables as Lance datasets in a filesystem directory structure.

Modules

manifest
Manifest-based namespace implementation
manifest_feature_flags
Reader/writer feature flags for the directory-catalog __manifest dataset.

Structs

DirectoryNamespace
Directory-based implementation of Lance Namespace.
DirectoryNamespaceBuilder
Builder for creating a DirectoryNamespace.
OpsMetrics
Thread-safe metrics tracker for namespace operations.