pub enum VendedPermission {
Read,
Write,
Admin,
}Expand description
Permission level for vended credentials.
This determines what access the vended credentials will have:
Read: Read-only access to all table contentWrite: Full read and write access (no delete)Admin: Full read, write, and delete access
Permission enforcement by cloud provider:
- AWS: Permissions are enforced via scoped IAM policies attached to the AssumeRole request
- Azure: Permissions are enforced via SAS token permissions
- GCP: Permissions are enforced via Credential Access Boundaries (CAB) that downscope the OAuth2 token to specific GCS IAM roles
Variants
Read
Read-only access to all table content (metadata, indices, data files)
Write
Full read and write access (no delete) This is intended ONLY for testing purposes to generate a write-only permission set. Technically, any user with write permission could “delete” the file by overwriting the file with empty content. So this cannot really prevent malicious use cases.
Admin
Full read, write, and delete access
Implementations