Directory-based Lance Namespace implementation.
This module provides a directory-based implementation of the Lance namespace that stores tables as Lance datasets in a filesystem directory structure.
Modules
- manifest
- Manifest-based namespace implementation
- manifest_
feature_ flags - Reader/writer feature flags for the directory-catalog
__manifestdataset.
Structs
- Directory
Namespace - Directory-based implementation of Lance Namespace.
- Directory
Namespace Builder - Builder for creating a DirectoryNamespace.
- OpsMetrics
- Thread-safe metrics tracker for namespace operations.